@@ -64,5 +64,9 @@ export.sc_overlap <- function(object, caption = NA, footnote = NA,
   table <- do.call(kable_styling, kable_styling_options)
   if (!is.na(footnote) && footnote != "") 
     table <- footnote(table, general = footnote, threeparttable = TRUE)
+ 
+  # finish ------------------------------------------------------------------
+  
+  if (!is.na(filename)) cat(table, file = filename)
   table
 }
