@@ -1,27 +1,26 @@
 #' Percentage of all non-overlapping data
-#' 
-#' The \code{pand} function calculates the percentage of all non-overlapping
-#' data (PAND; Parker, Hagan-Burke, & Vannest, 2007), an index to quantify a
-#' level increase (or decrease) in performance after the onset of an
-#' intervention.
-#' 
-#' The PAND indicates nonoverlap between phase A and B data (like \code{PND}),
-#' but uses all data and is therefore not based on one single (probably
-#' unrepresentative) datapoint.  Furthermore, PAND allows the comparison of
-#' real and expected associations (Chi-square test) and estimation of the
-#' effect size Phi, which equals Pearsons r for dichotomous data.  Thus,
-#' phi-Square is the amount of explained variance. The original procedure for
-#' computing the PAND (Parker, Hagan-Burke, & Vannest, 2007) does not account
-#' for ambivalent datapoints (ties).  The newer \code{NAP} overcomes this
-#' problem and has better precision-power (Parker, Vannest, & Davis, 2014).
-#' 
+#'
+#' The `pand()` function calculates the percentage of all non-overlapping data
+#' (PAND; Parker, Hagan-Burke, & Vannest, 2007), an index to quantify a level
+#' increase (or decrease) in performance after the onset of an intervention.
+#'
+#' The PAND indicates nonoverlap between phase A and B data, but uses
+#' all data and is therefore not based on one single (probably unrepresentative)
+#' datapoint.  Furthermore, PAND allows the comparison of real and expected
+#' associations (Chi-square test) and estimation of the effect size Phi, which
+#' equals Pearsons r for dichotomous data.  Thus, phi-Square is the amount of
+#' explained variance. The original procedure for computing the PAND (Parker,
+#' Hagan-Burke, & Vannest, 2007) does not account for ambivalent datapoints
+#' (ties).  The newer *nap* ([nap()]) overcomes this problem and has better
+#' precision-power (Parker, Vannest, & Davis, 2014).
+#'
 #' @inheritParams .inheritParams
-#' @param correction The default \code{correction = TRUE} makes \code{pand} use
-#' a frequency matrix, which is corrected for ties. A tie is counted as the
-#' half of a measurement in both phases. Set \code{correction = FALSE} to use
-#' the uncorrected matrix, which is not recommended.
+#' @param correction The default `correction = TRUE` makes `pand` use a
+#'   frequency matrix, which is corrected for ties. A tie is counted as the half
+#'   of a measurement in both phases. Set `correction = FALSE` to use the
+#'   uncorrected matrix, which is not recommended.
 #' @return \item{pand}{Percentage of all non-overlapping data.}
-#' \item{phi}{Effect size Phi based on expected and observed values.}
+#'   \item{phi}{Effect size Phi based on expected and observed values.}
 #' \item{perc_overlap}{Percentage of overlapping data points.} \item{overlaps}{Number of
 #' overlapping data points.} \item{n}{Number of data points.} \item{N}{Number
 #' of cases.} \item{nA}{Number of data points in phase A.} \item{nB}{Number of
@@ -31,18 +30,19 @@
 #' of phase A and B comparisons.} \item{correlation}{A list of the
 #' \code{correlation} values: statistic, parameter, p.value, estimate,
 #' null.value, alternative, method, data.name, correction.}
-#' \item{correction}{Logical argument from function call (see \code{Arguments}
+#' \item{correction}{Logical argument from function call (see `Arguments`
 #' above).}
 #' @author Juergen Wilbert
 #' @family overlap functions
 #' @references Parker, R. I., Hagan-Burke, S., & Vannest, K. (2007). Percentage
-#' of All Non-Overlapping Data (PAND): An Alternative to PND. \emph{The Journal
-#' of Special Education, 40}, 194-204.
-#' 
-#' Parker, R. I., & Vannest, K. (2009). An Improved Effect Size for Single-Case
-#' Research: Nonoverlap of All Pairs. \emph{Behavior Therapy, 40}, 357-367.
+#'   of All Non-Overlapping Data (PAND): An Alternative to PND. *The Journal of
+#'   Special Education, 40*, 194-204.
+#'
+#'   Parker, R. I., & Vannest, K. (2009). An Improved Effect Size for
+#'   Single-Case Research: Nonoverlap of All Pairs. *Behavior Therapy, 40*,
+#'   357-367.
 #' @examples
-#' 
+#'
 #' ## Calculate the PAND for a MMBD over three cases
 #' gunnar <- scdf(c(2,3,1,5,3,4,2,6,4,7), B_start = 5)
 #' birgit <- scdf(c(3,3,2,4,7,4,2,1,4,7), B_start = 4)
@@ -50,11 +50,11 @@
 #' mbd <- c(gunnar, birgit, bodo)
 #' pand(mbd)
 #' pand(bodo)
-#' 
+#'
 #' ## Calculate the PAND with an expected decrease of phase B scores
 #' cubs <- scdf(c(20,22,24,17,21,13,10,9,20,9,18), B_start = 5)
 #' pand(cubs, decreasing = TRUE)
-#' 
+#'
 #' @export
 pand <- function(data, dvar, pvar, 
                  decreasing = FALSE, 
@@ -62,14 +62,14 @@ pand <- function(data, dvar, pvar,
                  phases = c(1, 2)) {
   
   # set default attirubtes
-  if (missing(dvar)) dvar <- scdf_attr(data, .opt$dv)
-  if (missing(pvar)) pvar <- scdf_attr(data, .opt$phase)
+  if (missing(dvar)) dvar <- dv(data)
+  if (missing(pvar)) pvar <- phase(data)
   
-  scdf_attr(data, .opt$dv) <- dvar
-  scdf_attr(data, .opt$phase) <- pvar
+  dv(data) <- dvar
+  phase(data) <- pvar
   
   data <- .prepare_scdf(data, na.rm = TRUE)
-  data <- .keep_phases(data, phases = phases)$data
+  data <- recombine_phases(data, phases = phases)$data
 
   N <- length(data)
   
@@ -150,8 +150,8 @@ pand <- function(data, dvar, pvar,
   )
   
   class(out) <- c("sc_pand")
-  attr(out, .opt$phase) <- pvar
-  attr(out, .opt$dv) <- dvar
+  attr(out, opt("phase")) <- pvar
+  attr(out, opt("dv")) <- dvar
   out
 }
 
