@@ -1,3 +1,12 @@
+
+
+opt <- function(x) {
+  out <- .opt[[x]]
+  if (is.null(out)) stop("Option ", x, " not defined.")
+  out
+}
+
+
 # Basic options -----------------------------------------------------------
 
 .opt <- list(
@@ -9,21 +18,15 @@
   info         = "info",
   author       = "author",
   rigorous_class_check = TRUE, 
-  neutral.names = .neutral.names,
-  female.names = .female.names,
-  male.names   = .male.names,
-  names        = .names,
   names_default = paste0("Case", 1:500),
-  function_experimental_warning  = "This function is in an experimental state. The syntax and behaviour will probably change in a future version.",
-  function_deprecated_warning = "This function is deprecated. It might be dropped without any further notice in a future update of scan.",
-  #startup_message = paste0(
-  #  "\033[34m", 
-  #  "scan ",utils::packageVersion("scan")," (",utils::packageDate('scan'),")\n",
-  #  "Single-Case Data Analysis for Single and Multiple Baseline Designs\n",
-  #  "\033[31m",
-  #  "\n",
-  #  .opt$citation
-  #), 
+  function_experimental_warning  = paste(
+    "This function is in an experimental state.",
+    "The syntax and behaviour will probably change in a future version."
+  ),
+  function_deprecated_warning = paste(
+    "This function is deprecated. It might be dropped without any further",
+    "notice in a future update of scan."
+  ),
   style = list()
   )
 
