@@ -11,10 +11,10 @@ sample_names <- function(n = 1, type = "neutral", seed = NULL) {
   
   if (!is.null(seed)) set.seed(seed)
   out <- character(0)
-  if (type == "neutral") out <- sample(.opt$neutral.names, n)
-  if (type == "female") out <- sample(.opt$female.names, n)
-  if (type == "male") out <- sample(.opt$male.names, n)
-  if (type == "mixed") out <- sample(.opt$names, n)
+  if (type == "neutral") out <- sample(case_names$neutral, n)
+  if (type == "female") out <- sample(case_names$female, n)
+  if (type == "male") out <- sample(case_names$male, n)
+  if (type == "mixed") out <- sample(case_names$all, n)
   
   out
 }
